/*
 This file is part of the digitalSTROM ds485-daemon (ds485d).

 The code is based on the Avahi example:
 http://avahi.org/download/doxygen/client-publish-service_8c-example.html

 Copyright (C) 2014 digitalSTROM.org, Schlieren, Switzerland

 digitalSTROM ds485-daemon is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation version 2
 of the License.

 digitalSTROM ds485-daemon is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with digitalSTROM ds485-daemon; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef __DS485_AVAHI_H__
#define __DS485_AVAHI_H__

#include <avahi-client/publish.h>
#include <avahi-common/simple-watch.h>

/* instance structure */
struct ds485d
{
    unsigned short port;
    AvahiEntryGroup *avahi_group;
    AvahiSimplePoll *avahi_poll;
    AvahiClient *avahi_client;
    char *avahi_name;
    char *ds485d_dsuid;
};

typedef struct ds485d ds485d_t;

enum
{
    DS485D_DISCOVERY_OK = 0,            /*!< no error */
    DS485D_DISCOVERY_ERR_PARAM = -1,    /*!< error discovery parameter */
    DS485D_ERR_OUT_OF_MEMORY  = -2      /*!< error allocating memory */
};

int ds485d_discovery_init(ds485d_t *handle, const char *name);
void ds485d_discovery_work(ds485d_t *handle);
void ds485d_discovery_cleanup(ds485d_t *handle);

#endif//__DS485_AVAHI_H__

